Configure tobiko logs directory to be accessible for ``stack`` user.

**Role Variables**

.. zuul:rolevar:: tobiko_logsdir
   :default: /opt/stack/tobiko_logs

   Name of the directory where Tobiko configs will be stored.
